==> jc-1.4.0.tar.gz: soot/jimple/internal/JStaticInvokeExpr.h <==
// public class soot.jimple.internal.JStaticInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class d05daebe237ff109 soot_jimple_internal_AbstractStaticInvokeExpr
// @dep_class 2489131021df42e0 soot_jimple_internal_JStaticInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStaticInvokeExpr

#include "soot/jimple/internal/AbstractStaticInvokeExpr.h"

#ifndef _JC_soot_jimple_internal_JStaticInvokeExpr_H_
#define _JC_soot_jimple_internal_JStaticInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JStaticInvokeExpr$sub_refs	_jc_soot_jimple_internal_JStaticInvokeExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JStaticInvokeExpr$sub_nonrefs	_jc_soot_jimple_internal_JStaticInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JStaticInvokeExpr$refs	_jc_soot_jimple_internal_JStaticInvokeExpr$refs;
typedef struct _jc_soot_jimple_internal_JStaticInvokeExpr$nonrefs	_jc_soot_jimple_internal_JStaticInvokeExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JStaticInvokeExpr$object	_jc_soot_jimple_internal_JStaticInvokeExpr$object;

typedef const struct _jc_soot_jimple_internal_JStaticInvokeExpr$vmethods	_jc_soot_jimple_internal_JStaticInvokeExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JStaticInvokeExpr$vtable	_jc_soot_jimple_internal_JStaticInvokeExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JStaticInvokeExpr$vtype	_jc_soot_jimple_internal_JStaticInvokeExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JStaticInvokeExpr$method$_init$6327f5fb7966d9c6(_jc_env *, struct _jc_soot_jimple_internal_JStaticInvokeExpr$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);
extern void _jc_soot_jimple_internal_JStaticInvokeExpr$method$_init$cc0a1b4e01b646aa(_jc_env *, struct _jc_soot_jimple_internal_JStaticInvokeExpr$object *, struct _jc_soot_SootMethod$object *, struct _jc_object_array *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JStaticInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JStaticInvokeExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JStaticInvokeExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JStaticInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JStaticInvokeExpr$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JStaticInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractStaticInvokeExpr$vmethods	soot_jimple_internal_AbstractStaticInvokeExpr;
	_jc_soot_jimple_internal_JStaticInvokeExpr$vmethods	soot_jimple_internal_JStaticInvokeExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JStaticInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JStaticInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JStaticInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JStaticInvokeExpr$refs {
    _jc_soot_jimple_internal_JStaticInvokeExpr$sub_refs	soot_jimple_internal_JStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_refs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JStaticInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JStaticInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_jimple_internal_JStaticInvokeExpr$sub_nonrefs	soot_jimple_internal_JStaticInvokeExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JStaticInvokeExpr$object {
	_jc_soot_jimple_internal_JStaticInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JStaticInvokeExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JStaticInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JStaticInvokeExpr$vtype _jc_soot_jimple_internal_JStaticInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JStaticInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JStaticInvokeExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JStaticInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JStaticInvokeExpr.h <==
// public class soot.jimple.internal.JStaticInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr
// @dep_class d05daebe237ff109 soot_jimple_internal_AbstractStaticInvokeExpr
// @dep_class 2489131021df42e0 soot_jimple_internal_JStaticInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractStaticInvokeExpr

#include "soot/jimple/internal/AbstractStaticInvokeExpr.h"

#ifndef _JC_soot_jimple_internal_JStaticInvokeExpr_H_
#define _JC_soot_jimple_internal_JStaticInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JStaticInvokeExpr$sub_refs	_jc_soot_jimple_internal_JStaticInvokeExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JStaticInvokeExpr$sub_nonrefs	_jc_soot_jimple_internal_JStaticInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JStaticInvokeExpr$refs	_jc_soot_jimple_internal_JStaticInvokeExpr$refs;
typedef struct _jc_soot_jimple_internal_JStaticInvokeExpr$nonrefs	_jc_soot_jimple_internal_JStaticInvokeExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JStaticInvokeExpr$object	_jc_soot_jimple_internal_JStaticInvokeExpr$object;

typedef const struct _jc_soot_jimple_internal_JStaticInvokeExpr$vmethods	_jc_soot_jimple_internal_JStaticInvokeExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JStaticInvokeExpr$vtable	_jc_soot_jimple_internal_JStaticInvokeExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JStaticInvokeExpr$vtype	_jc_soot_jimple_internal_JStaticInvokeExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JStaticInvokeExpr$method$_init$6327f5fb7966d9c6(_jc_env *, struct _jc_soot_jimple_internal_JStaticInvokeExpr$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_JStaticInvokeExpr$method$_init$cc0a1b4e01b646aa(_jc_env *, struct _jc_soot_jimple_internal_JStaticInvokeExpr$object *, struct _jc_soot_SootMethod$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JStaticInvokeExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JStaticInvokeExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JStaticInvokeExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JStaticInvokeExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JStaticInvokeExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JStaticInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractStaticInvokeExpr$vmethods	soot_jimple_internal_AbstractStaticInvokeExpr;
	_jc_soot_jimple_internal_JStaticInvokeExpr$vmethods	soot_jimple_internal_JStaticInvokeExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JStaticInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JStaticInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JStaticInvokeExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JStaticInvokeExpr$refs {
    _jc_soot_jimple_internal_JStaticInvokeExpr$sub_refs	soot_jimple_internal_JStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_refs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JStaticInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JStaticInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractStaticInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractStaticInvokeExpr;
    _jc_soot_jimple_internal_JStaticInvokeExpr$sub_nonrefs	soot_jimple_internal_JStaticInvokeExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JStaticInvokeExpr$object {
	_jc_soot_jimple_internal_JStaticInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JStaticInvokeExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JStaticInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JStaticInvokeExpr$vtype _jc_soot_jimple_internal_JStaticInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JStaticInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JStaticInvokeExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JStaticInvokeExpr_H_ */
